# emailer
Basic emailing interface

## Quickstart

### env vars

| env | description |
| --- | --- |
| EMAILER_SENDER_ADDR | sender-addresse |
| EMAILER_SENDER_PW | sender-password |
| EMAILER_PROVIDER | sender-provider |
| EMAILER_PORT | sender-port |